# express-access-guard

Access control module for express.

## Usage

```js
const Express = require('express')

const app = Express()

// auth user
app.use((req, res, next) => {
  req.user = {
    permissions: [ 'photo' ]
  }
})

const guard = require('express-access-guard')({
  userProperty: 'user', // property thats contains user object, default "user"
  permissionsProperty: 'permissions', // property in user object that contains permissions list, default 'permissions'
  ForbiddenError: Error // error that throws (to next callback) if user has invalid permissions, default Error
})

app.get(
  '/photos',
  // user must have one permission "photo" or "admin" to see photos
  guard.some([ 'photo', 'admin' ]),
  (req, res) => {
    // do your stuff
  }
)

app.delete(
  '/photos',
  // user must have all permission "photo" and "admin" to delete photos
  guard.every([ 'photo', 'admin' ]),
  (req, res) => {
    // do your stuff
  }
)
```
